==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/ko.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "첫 실행 마법사",
    "Add your profile information! For example your email is needed to reset your password." : "내 프로필 정보를 추가하십시오! 이메일 주소는 암호를 초기화하는 데 필요합니다.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "내 프로필 정보를 추가하십시오! 프로필 사진과 이름을 입력하면 사용자를 빠르게 식별할 수 있습니다.",
    "Add your profile information! Set a full name for easier recognition across all features." : "내 프로필 정보를 추가하십시오! 이름을 입력하면 사용자를 빠르게 식별할 수 있습니다.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "내 프로필 정보를 추가하십시오! 프로필 사진을 지정하면 사용자를 빠르게 식별할 수 있습니다.",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "내 파일, 달력, 연락처, 이메일을 내가 원하는 모든 장소에서 접근하고 공유하기",
    "Get the apps to sync your files" : "파일 동기화 앱 가져오기",
    "Desktop client" : "데스크톱 클라이언트",
    "Android app" : "Android 앱",
    "iOS app" : "iOS 앱",
    "Connect your desktop apps to %s" : "내 데스크톱 앱을 %s에 연결하기",
    "Connect your Calendar" : "내 달력 연결하기",
    "Connect your Contacts" : "내 연락처 연결하기",
    "Access files via WebDAV" : "WebDAV로 파일에 접근하기",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "<a target=\"_blank\" href=\"%s\">문서</a> 및 <a target=\"_blank\" href=\"%s\">웹 사이트</a>에서 더 많은 정보를 찾으십시오.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Nextcloud를 좋아하신다면 <a href=\"mailto:?subject=Nextcloud &body=Nextcloud는 내 파일을 동기화하고 공유할 수 있는 오픈 소스 소프트웨어입니다. https://nextcloud.com 사이트에서 무료로 다운로드할 수 있습니다\">친구에게 추천</a>하거나 <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">기여</a>하실 수 있습니다다!"
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/ko.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "첫 실행 마법사",
    "Add your profile information! For example your email is needed to reset your password." : "내 프로필 정보를 추가하십시오! 이메일 주소는 암호를 초기화하는 데 필요합니다.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "내 프로필 정보를 추가하십시오! 프로필 사진과 이름을 입력하면 사용자를 빠르게 식별할 수 있습니다.",
    "Add your profile information! Set a full name for easier recognition across all features." : "내 프로필 정보를 추가하십시오! 이름을 입력하면 사용자를 빠르게 식별할 수 있습니다.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "내 프로필 정보를 추가하십시오! 프로필 사진을 지정하면 사용자를 빠르게 식별할 수 있습니다.",
    "Get the apps to sync your files" : "파일 동기화 앱 가져오기",
    "Desktop client" : "데스크톱 클라이언트",
    "Android app" : "Android 앱",
    "iOS app" : "iOS 앱",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "내 파일, 달력, 연락처, 이메일을 내가 원하는 모든 장소에서 접근하고 공유하기",
    "Connect your desktop apps to %s" : "내 데스크톱 앱을 %s에 연결하기",
    "Access files via WebDAV" : "WebDAV로 파일에 접근하기",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "<a target=\"_blank\" href=\"%s\">문서</a> 및 <a target=\"_blank\" href=\"%s\">웹 사이트</a>에서 더 많은 정보를 찾으십시오.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Nextcloud를 좋아하신다면 <a href=\"mailto:?subject=Nextcloud &body=Nextcloud는 내 파일을 동기화하고 공유할 수 있는 오픈 소스 소프트웨어입니다. https://nextcloud.com 사이트에서 무료로 다운로드할 수 있습니다\">친구에게 추천</a>하거나 <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">기여</a>하실 수 있습니다다!",
    "Connect your Calendar" : "내 달력 연결하기",
    "Connect your Contacts" : "내 연락처 연결하기"
},
"nplurals=1; plural=0;");
